@@ -24,7 +24,7 @@
 #include <android/log.h>
 #include "org_kiwix_kiwixlib_JNIKiwixReader.h"
 
-#include "common/base64.h"
+#include "tools/base64.h"
 #include "reader.h"
 #include "utils.h"
 
@@ -163,8 +163,7 @@ Java_org_kiwix_kiwixlib_JNIKiwixReader_getFavicon(JNIEnv* env, jobject obj)
     std::string cMime;
     READER->getFavicon(cContent, cMime);
     favicon = c2jni(
-        base64_encode(reinterpret_cast<const unsigned char*>(cContent.c_str()),
-                      cContent.length()),
+        base64_encode(cContent),
         env);
   } catch (std::exception& e) {
     __android_log_print(ANDROID_LOG_ERROR, "kiwix", "Unable to get ZIM favicon");
