@@ -9,14 +9,16 @@ ARCHIVE_NAME=deps_${TRAVIS_OS_NAME}_${PLATFORM}_${REPO_NAME}.tar.gz
 cd $HOME
 if [[ "$TRAVIS_OS_NAME" == "osx" ]]
 then
-  brew update
-  brew upgrade python3
-  pip3 install meson==0.43.0
+  pip3 install meson
 
   wget https://github.com/ninja-build/ninja/releases/download/v1.8.2/ninja-mac.zip
   unzip ninja-mac.zip ninja
 else
-  pip3 install --user meson==0.43.0
+  wget https://bootstrap.pypa.io/get-pip.py
+  python3.5 get-pip.py --user
+
+  python3.5 -m pip install --user --upgrade pip
+  python3.5 -m pip install --user meson
 
   wget https://github.com/ninja-build/ninja/releases/download/v1.8.2/ninja-linux.zip
   unzip ninja-linux.zip ninja
